package jelathro.android.halloweenapp;

import java.util.HashMap;
import java.util.Random;

import android.os.Bundle;
import android.app.Activity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.WindowManager;

import android.content.Context;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;

import android.media.MediaPlayer;

import android.widget.Button;
import android.graphics.PorterDuff;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.widget.EditText;
import android.view.LayoutInflater;

public class MainActivity extends Activity implements SensorEventListener {
	
	// Accelerometer
	private float mLastZ;
	private boolean mInitialized;
	private SensorManager mSensorManager;
	private Sensor mAccelerometer;
	private float NOISE = (float) 0.25;
	
	// MP3 Player
	private Random random = new Random(2435454);
	private HashMap<Integer, MediaPlayer> sounds;
	private int sound = 0;
	
	private void stopSounds(){
		// Stop all sounds.
		for(int i=0; i < sounds.size(); i++){
			if(sounds.get(i).isPlaying()){
				sounds.get(i).pause();
				sounds.get(i).seekTo(0);
			}
		}
		
		// Update to next random sound.
		sound = random.nextInt(3);
	}
	
	private void stopSound(MediaPlayer mp){
		if(mp.isPlaying()){
			mp.pause();
			mp.seekTo(0);
		}
		
		// Update to next random sound.
		sound = random.nextInt(3);
	}
	
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
        
        mInitialized = false;
        mSensorManager = (SensorManager) getSystemService(Context.SENSOR_SERVICE);
        mAccelerometer = mSensorManager.getDefaultSensor(Sensor.TYPE_ACCELEROMETER);
        mSensorManager.registerListener(this, mAccelerometer, SensorManager.SENSOR_DELAY_NORMAL);

        // MediaPlayers
        sounds = new HashMap<Integer, MediaPlayer>();
        sounds.put(0, MediaPlayer.create(this, R.raw.evillaughinhall));
        sounds.put(1, MediaPlayer.create(this, R.raw.evilwitchlaughing));
        sounds.put(2, MediaPlayer.create(this, R.raw.laugh2));
        
        for(int i=0; i < sounds.size(); i++){
        	sounds.get(i).setOnCompletionListener(new MediaPlayer.OnCompletionListener(){
        		public void onCompletion(MediaPlayer mp){
        			stopSound(mp);
        		}
        	});
        }
        
        // Buttons
        final Button playButton = (Button) findViewById(R.id.play_sound);
        final Button stopButton = (Button) findViewById(R.id.stop_sound);
        
        playButton.getBackground().setColorFilter(0xFFFF0000, PorterDuff.Mode.DARKEN);
        stopButton.getBackground().setColorFilter(0xFFFF0000, PorterDuff.Mode.DARKEN);
        
        playButton.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				if(!sounds.get(sound).isPlaying()){
					sounds.get(sound).start();
				}
			}
		});

        stopButton.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View v) {
				stopSounds();
			}
		});
    }

    protected void onResume() {
    	super.onResume();
    	mSensorManager.registerListener(this,  mAccelerometer, SensorManager.SENSOR_DELAY_NORMAL);
    }
    
    protected void onPause() {
    	super.onPause();
    	mSensorManager.unregisterListener(this);
    	stopSounds();
    }
    
    @Override
    public void onAccuracyChanged(Sensor sensor, int accuracy) {
    	// can be safely ignored for this demo.
    }
    
    @Override
    public void onSensorChanged(SensorEvent event) {
	    float z = event.values[2];
	    
	    if (!mInitialized) {
		    mLastZ = z;
		    mInitialized = true;
	    } else {
		    if (Math.abs(mLastZ - z) > NOISE){
				if(!sounds.get(sound).isPlaying()){
					sounds.get(sound).start();
				}
		    }
		    mLastZ = z;
	    }
	}
    
    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.main, menu);
        return true;
    }
    
    @Override
    public boolean onOptionsItemSelected(MenuItem item){
    	switch(item.getItemId()){
    	case R.id.sensitivity:
    		// Dialog stuff
    		LayoutInflater li = LayoutInflater.from(this);
    		View promptsView = li.inflate(R.layout.prompt, null);

    		AlertDialog.Builder alertDialogBuilder = new AlertDialog.Builder(this);

    		// set prompts.xml to alertdialog builder
    		alertDialogBuilder.setView(promptsView);

    		final EditText userInput = (EditText) promptsView.findViewById(R.id.sensitivityInput);

    		// set dialog message
    		alertDialogBuilder.setCancelable(false).setPositiveButton("OK",
    		  new DialogInterface.OnClickListener() {
    		    public void onClick(DialogInterface dialog,int id) {
    				// get user input and set it to result
    				// edit text
    				NOISE = Float.parseFloat(userInput.getText().toString());
    		    }
    		  }).setNegativeButton("Cancel",
    		  new DialogInterface.OnClickListener() {
    		    public void onClick(DialogInterface dialog,int id) {
    			dialog.cancel();
    		    }
    		  });

    		// create alert dialog
    		AlertDialog alertDialog = alertDialogBuilder.create();

    		// show it
    		alertDialog.show();
    		break;
		default:
			break;
    	}
    	return super.onOptionsItemSelected(item);
    }
    
}
